| data_heart_obsL | R Documentation |
3D meshes for the complete heart and for a surrogate volume of the aortic valve from one patient, as delineated by 3 observers. No gold standard.
data(data_heart_obsL)
Object of class list with 3 components (Obs01, Obs02, Obs03), each representing one observer. Each of these lists contains two meshes - the complete heart, and a surrogate volume for the aortic valve. For Obs01, the list has this structure:
Obs01_HEARTMesh object - a list with components name, mesh, volume, centroid, where mesh is a mesh3d object.
Obs01_AOKLMesh object with the same structure as Obs01_HEART.
Use mesh3dL_to_cgalMeshL to convert mesh3d objects to cgalMesh objects that other functions expect. Data courtesy of the Department of Radiation Oncology, University Medical Center Mainz, Germany.
mesh3d,
read_mesh,
get_mesh_info
heartL <- mesh3dL_to_cgalMeshL(data_heart_obsL) get_mesh_info(heartL)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.