get_mesh_info: Get information about a list of oberver/mesh objects
Description
Get key information about a list of observer/mesh objects. This includes the respective number of vertices and triangles of the meshes as well as their volume and centroid.
Usage
get_mesh_info(x)
Value
data.frame with these variables
observer
Name of the observer.
name
Name of the mesh.
n_verts
Number of vertices.
n_faces
Number of faces.
volume
Mesh volume.
ctr_x
Centroid x-coordinate.
ctr_y
Centroid y-coordinate.
ctr_z
Centroid z-coordinate.
Arguments
x
list of observer/mesh objects with a structure as generated by read_mesh.
Details
Use get_mesh_info_one for getting the information about a single mesh object. Use get_mesh_info_obs for getting the information about a list of meshes.