| get_mesh_metro_pair | R Documentation |
Calculate distances between two 3D meshes. Used for distance-based agreement measures such as the Hausdorff distance or the average surface distance.
get_mesh_metro_pair(x, chop=TRUE, ...)
x |
|
chop |
|
... |
Options passed to |
Thin front-end for vcgMetro. Use get_mesh_metro to process all pairs from a list of 3D meshes. Post-processing for agreement measures is done in get_mesh_agree_pair.
list with object returned by vcgMetro together with the name of the comparison and a name for the structure.
http://vcg.isti.cnr.it/vcglib/
get_mesh_pairs,
get_mesh_metro,
get_mesh_agree_pair,
vcgMetro
heartL <- mesh3dL_to_cgalMeshL(data_heart_obsL)
pairL <- get_mesh_pairs(heartL)
metro <- get_mesh_metro_pair(pairL[[1]], nSamples=500L, silent=TRUE)
# Hausdorff distance
get_HD_max <- function(x) {
max(c(x$ForwardSampling$maxdist,
x$BackwardSampling$maxdist))
}
get_HD_max(metro)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.