| get_mesh_ui | R Documentation |
Calculates the respective union and intersection for pairs from a list of 3D mesh objects.
get_mesh_ui(x, boov=FALSE)
x |
|
boov |
|
Pairs are assigned as the corresponding objects in x from the included observers. The respective first meshes from each observer are compared, then the respective second meshes, and so on. Front-end for union and intersection methods of the cgalMesh class. Both are based on the CGAL library for computational geometry. Use get_mesh_ui_pair to get the union and intersection for a single pair of meshes. For boov=TRUE, package Boov has to be installed separately.
list of lists with two cgalMesh objects for the union and intersection as well as the name of the comparison and a name for the structure.
data_heart_obsL,
read_mesh,
get_mesh_ui_pair,
cgalMesh
heartL <- mesh3dL_to_cgalMeshL(data_heart_obsL)
## remove one structure to save time in running example
heartL$Obs01$Obs01_HEART <- NULL
heartL$Obs02$Obs02_HEART <- NULL
heartL$Obs03$Obs03_HEART <- NULL
## takes more time than reasonable for automated checking
if(interactive()) {
uiL <- get_mesh_ui(heartL)
## volume of union/intersection for first pair
uiL[[1]]$vol_u
uiL[[1]]$vol_i
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.