| get_mesh_ui_pair | R Documentation |
Calculates the union and intersection of a single pair of 3D mesh objects.
get_mesh_ui_pair(x, boov=FALSE)
x |
|
boov |
|
Front-end for the union / intersection methods of the cgalMesh class. Both are based on the CGAL library for computational geometry. Use get_mesh_ui to get the respective union and intersection for all pairs from a list of 3D meshes. For boov=TRUE, package Boov has to be installed separately.
list of two cgalMesh objects for the union and intersection as well as the name of the comparison and a name for the structure.
get_mesh_pairs,
get_mesh_ui,
get_mesh_agree_pair,
cgalMesh
heartL <- mesh3dL_to_cgalMeshL(data_heart_obsL) pairL <- get_mesh_pairs(heartL) ui <- get_mesh_ui_pair(pairL[[4]]) ## volume of union/intersection ui$vol_u ui$vol_i
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.