| read_mesh | R Documentation |
Read several mesh objects each for several observers from files.
read_mesh(x, name, fix_issues=TRUE,
reconstruct=c("No", "AFS", "Poisson"),
spacing=1)
x |
|
name |
|
fix_issues |
|
reconstruct |
|
spacing |
Controls vertex spacing for |
Supported file formats: STL, PLY, OBJ, OFF. For subsequent comparison, the first file from observer 1 will be paired with the first file from observer 2, and so on.
list (each component representing one observer) of lists of mesh objects. Each object is a list with components name, mesh, volume, centroid, where mesh is a cgalMesh object. Sample object given in data_heart_obsL. Use read_mesh_obs to read several mesh files from one observer. Use read_mesh_one to read a single mesh file.
cgalMesh,
data_heart_obsL,
read_mesh_obs,
read_mesh_one,
if(interactive()) {
src_dir <- system.file("extdata", package="MeshAgreement")
ff1 <- list.files(src_dir, pattern="^Obs01", full.names=TRUE)
ff2 <- list.files(src_dir, pattern="^Obs02", full.names=TRUE)
ff3 <- list.files(src_dir, pattern="^Obs03", full.names=TRUE)
obsL <- read_mesh(list(Obs01=ff1,
Obs02=ff2,
Obs03=ff3),
reconstruct="AFS")
get_mesh_info(obsL)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.