| read_mesh_obs | R Documentation |
Read a list of mesh objects from one observer from files.
read_mesh_obs(x, name, fix_issues=TRUE,
reconstruct=c("No", "AFS", "Poisson"),
spacing=1)
x |
|
name |
|
fix_issues |
|
reconstruct |
|
spacing |
Controls vertex spacing for |
Supported file formats: STL, PLY, OBJ, OFF.
List of mesh objects. Each object is a list with components name, mesh, volume, centroid, where mesh is a cgalMesh object. Use read_mesh to read a list of several mesh objects each for several observers. Use read_mesh_one to read a single mesh file.
cgalMesh,
read_mesh,
read_mesh_one,
if(interactive()) {
src_dir <- system.file("extdata", package="MeshAgreement")
ff <- list.files(src_dir, pattern="^Obs01", full.names=TRUE)
meshL <- read_mesh_obs(ff, reconstruct="AFS")
get_mesh_info_obs(meshL)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.