| read_mesh_one | R Documentation |
Read one mesh object from a file.
read_mesh_one(x, name, fix_issues=TRUE,
reconstruct=c("No", "AFS", "Poisson"),
spacing=1)
x |
|
name |
|
fix_issues |
|
reconstruct |
|
spacing |
Controls vertex spacing for |
Supported file formats: STL, PLY, OBJ, OFF.
Mesh object - a list with components name, mesh, volume, centroid, where mesh is a cgalMesh object. Use read_mesh to read a list of several mesh objects each for several observers. Use read_mesh_obs to read a list of several mesh objects each for 1 observer.
cgalMesh,
read_mesh,
read_mesh_obs,
if(interactive()) {
src_dir <- system.file("extdata", package="MeshAgreement")
ff <- list.files(src_dir, pattern="^Obs01", full.names=TRUE)
mesh <- read_mesh_one(ff[1], reconstruct="AFS")
get_mesh_info_one(mesh)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.