| run_gui | R Documentation |
Opens a web-based GUI in an external browser.
run_gui(...)
... |
Arguments passed to |
This function calls runApp to run the included MeshAgreement application. Be aware that packages shiny, DT, bs4Dash, sortable need to be installed. Package Boov has to be installed as well if union / intersection volume should be computed via MeshesUnion / MeshesIntersection.
No return value, called for side effect of starting shiny app.
runApp
if(interactive()) {
run_gui()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.